process_update

Function process_update 

pub fn process_update(
    db: &Db,
    payload: &Value,
    max_body_size: usize,
    max_keys_per_request: usize,
) -> (u16, Value)
Handle an UPDATE (partial merge) request.

Merges the provided fields into existing documents without overwriting fields that are not mentioned in the update.

Format: { “collection”: “users”, “data”: { “u1”: { “role”: “admin” } } }